@@ -28,24 +28,23 @@ class ImagePreviewWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit ImagePreviewWidget(QWidget *parent = 0);
+    explicit ImagePreviewWidget(QWidget *parent = nullptr);
 
     void setImage(const QImage &preview);
 
-    QSize sizeHint() const Q_DECL_OVERRIDE;
+    QSize sizeHint() const override;
 
 Q_SIGNALS:
     void clicked();
 
 protected:
-    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
-    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
-    void mousePressEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *event) override;
+    void resizeEvent(QResizeEvent *event) override;
+    void mousePressEvent(QMouseEvent *event) override;
 
 private:
     QImage m_image;
     QImage m_scaledImage;
-    QPixmap m_frameImage;
 };
 
 }
